local AddonName, Addon = ...

-- Lib
local L = Addon.Libs.L
local DCL = Addon.Libs.DCL

-- Modules
local Core = Addon.Core
local DB = Addon.DB
local Game = Addon.Game
local MinimapIcon = Addon.MinimapIcon

-- ============================================================================
-- DethsAddonLib Functions
-- ============================================================================

function Core:OnInitialize()
  DB:Initialize()
  MinimapIcon:Initialize()
  
  -- Setup slash command
  DethsLibLoader("DethsCmdLib", "1.0"):Create(AddonName, function(cmd)
    -- ======================================================
    -- Icon
    -- ======================================================
    if (cmd == "icon") then
      if DB.Global.Minimap.hide then
        MinimapIcon:Show()
        Core:Print(L.MINIMAP_ICON_ENABLED_TEXT)
      else
        MinimapIcon:Hide()
        Core:Print(L.MINIMAP_ICON_DISABLED_TEXT)
      end
    -- ======================================================
    -- Music
    -- ======================================================
    elseif (cmd == "music") then
      local enable = not DB.Global.EnableMusic
      DB.Global.EnableMusic = enable
      self:Print(enable and L.MUSIC_ENABLED_TEXT or L.MUSIC_DISABLED_TEXT)
    -- ======================================================
    -- Clear
    -- ======================================================
    elseif (cmd == "clear") then
      Game:SetHighScore(0)
      self:Print(L.HIGH_SCORE_CLEARED_TEXT)
    -- ======================================================
    -- Default
    -- ======================================================
    else
      Game.Window:Toggle()
    end
  end)
  
  local f = CreateFrame("Frame")
	f:RegisterEvent("CHAT_MSG_GUILD")
	f:SetScript("OnEvent", function(self, event, message, sender)
		  if (message == '!LorgokBest') then 
			 SendChatMessage("Mein Score ist " .. DB.Global.HighScore .. "!","GUILD") 
		  end
	end)
  
end

-- ============================================================================
-- General Functions
-- ============================================================================

do
  local title = DCL:ColorString("["..AddonName.."]", Addon.TITLE_COLOR)
  function Core:Print(...) print(title, ...) end
end

--[[
function Core:Debug(title, ...)
  print(
    DCL:ColorString("["..AddonName.." Debug]", DCL.CSS.Crimson),
    DCL:ColorString(title, DCL.CSS.LightGreen),
    ...
  )
end
--]] Core.Debug = nop
