local AddonName, Addon = ...

-- Lib
local DGL = Addon.Libs.DGL

-- Game
local ParallaxBackground = Addon.ParallaxBackground
local Game = Addon.Game
local Spritesheet = Addon.Spritesheet

-- ============================================================================
-- General Functions
-- ============================================================================

function ParallaxBackground:Initialize()
  do -- Add static background
    local sprite = Spritesheet.Sprites.Background
    local bg = DGL.GameObject:Create(Game, "Background", 0, 0, "BACKGROUND")
    bg.Texture:SetTexture(Spritesheet.Path)
    bg.Texture:SetTexCoord(unpack(sprite.Coords))
    bg:SetWidth(sprite.Width)
    bg:SetHeight(sprite.Height)
  end

  do -- Add ground
    local sprite = Spritesheet.Sprites.Ground
    local ground = DGL.GameObject:Create(Game, "Ground", 0, Game.HEIGHT - sprite.Height, nil, Addon.Sublayers.Ground)
    ground.Texture:SetTexture(Spritesheet.Path)
    ground.Texture:SetTexCoord(unpack(sprite.Coords))
    ground:SetWidth(sprite.Width)
    ground:SetHeight(sprite.Height)

    -- Add tail texture
    ground.Tail = Game.WorldFrame:CreateTexture(nil, "ARTWORK", nil, Addon.Sublayers.Ground)
    ground.Tail:SetPoint("TOPLEFT", ground.Texture, "TOPRIGHT", 0, 0)
    ground.Tail:SetTexture(Spritesheet.Path)
    ground.Tail:SetTexCoord(unpack(sprite.Coords))
    ground.Tail:SetWidth(sprite.Width)
    ground.Tail:SetHeight(sprite.Height)

    function ground:OnUpdate(elapsed)
      if (Game:GetState() ~= Game.States.Playing) then return end
      -- Move
      self.X = self.X - (Addon.Column.Speed * elapsed)
      -- Wrap
      if (self.X <= -self.WIDTH) then self.X = 0 end
    end

    self.ground = ground
  end
  
  self.Initialize = nil
end

function ParallaxBackground:Reset()
  self.ground.X = 0
end
