local AddonName, Addon = ...

-- Libs
local DGL = Addon.Libs.DGL

-- Upvalues
local PlayMusic, StopMusic = PlayMusic, StopMusic

-- Modules
local Game = Addon.Game
local Playing = Game.States.Playing
local DB = Addon.DB
local ParallaxBackground = Addon.ParallaxBackground
local Player = Addon.Player
local Column = Addon.Column

-- Consts
local MUSIC_PATH = format("Interface\\Addons\\%s\\Assets\\bensound-dance.ogg", AddonName)

-- Variables
local isMusicPlaying = false

-- ============================================================================
-- Helper Functions
-- ============================================================================


local function play()
  Game.Input:SetEnabled(true)
  if DB.Global.EnableMusic then
    isMusicPlaying = true
    PlayMusic(MUSIC_PATH)
  end
end

local function stop()
  Game.Input:SetEnabled(false)
  if isMusicPlaying then
    isMusicPlaying = false
    StopMusic()
  end
end

-- ============================================================================
-- GameState Functions
-- ============================================================================

-- function Playing:Initialize() end

function Playing:OnEnter()
  Game:SetScore(0)
  
  ParallaxBackground:Reset()
  Player:Reset()
  Column:Reset()
  
  play()
end

Playing.OnLeave = stop
Playing.OnPause = stop
Playing.OnResume = play

function Playing:OnUpdate(elapsed)
  if Game.Input:IsMouseJustDown("RightButton") then
    return Game:PushState(Game.States.Paused)
  end
  
  Column:OnUpdate(elapsed)
  DGL.GameObject:OnUpdate(Game, elapsed)
end
